@@ -549,7 +549,11 @@ create_icon_widget(GdkPixbuf *icon_buffer, const char *icon_path, int icon_size,
 
 #ifdef HILDONANIMATION
     if (app->config->animation){
-        icon_widget = create_hildon_clutter_icon_animation(icon_path, icon_size, objects_list);
+#ifndef APPLICATION
+        if (app->applet_visible)
+#endif
+            icon_widget = create_hildon_clutter_icon_animation(icon_path, icon_size, objects_list);
+            
     }
     if (!icon_widget)
         icon_widget = gtk_image_new_from_pixbuf(icon_buffer);
